
/**************************************************************************
**  (c) Copyright 2002, Andromeda Technology & Automation
** This is free software; you can redistribute it and/or modify it under the
** terms of the GNU General Public License, see the file COPYING.
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : access_cooker.cpp
**      SYSTEM NAME    : 
**      VERSION NUMBER : $Revision: 1.3 $
**
**  DESCRIPTION      :  Cooks Apache http daemon access log lines
**
**  EXPORTED OBJECTS : 
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Aug 11, 2003
**      LAST UPDATE     : Aug 11, 2003
**      MODIFICATIONS   : 
**************************************************************************/

/*****************************
   $Log: access_cooker.cpp,v $
   Revision 1.3  2003/12/22 10:22:21  arjen
   Accept a wider range of input patterns

   Revision 1.2  2003/12/04 10:38:09  arjen
   Major redesign. All input is handled through XML. Raw input data is first
   transformed into an XML document for further processing.
   A collection of polymorphic classes handle the transformation of various
   input formats into XML.
   Classifying input data is done with a finite improbability calculation.

   Revision 1.1  2003/08/11 16:56:15  arjen
   Different kinds of log files are parsed by a collection of objects
   of different classes, derived from the base class line_cooker
   Depending on the message content or the message_type element in
   XML, one of these objects is selected.

   Logrunner is integrated with gcm_input. Although its functionality
   is still limited, a connection between logrunner and gcm_input
   is beginning to form.

*****************************/

/* static const char *RCSID = "$Id: access_cooker.cpp,v 1.3 2003/12/22 10:22:21 arjen Exp $"; */

#include <ctype.h>

#include "access_cooker.h"

static const regex re_accesslog("(GET|POST|HEAD|OPTIONS|CONNECT) .+ HTTP");

bool access_cooker::check_pattern(String logline)
{
   return logline == re_accesslog;
}

bool access_cooker::cook_this(String logline, UTC arrival)
{
   if (check_pattern(logline))
   {
      String datestring = logline(regex("\\[.+\\]"));

      datestring <<= 1;
      datestring >>= 1;
      datestring[datestring.index(':')] = ' ';

      date   log_date = datestring;
      hour   log_time = datestring;

      log_date = datestring;
      log_time = datestring;

      ts = UTC(log_date, log_time);

      hn  = "";
      srv = "httpd";

      return true;
   }
   else
   {
      return false;
   }
}


