
/**************************************************************************
**  (c) Copyright 2003, Andromeda Technology & Automation
** This is free software; you can redistribute it and/or modify it under the
** terms of the GNU General Public License, see the file COPYING.
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : string_utils.cpp
**      SYSTEM NAME    : Gnucomo - Gnu Computer Monitoring
**      VERSION NUMBER : $Revision: 1.3 $
**
**  DESCRIPTION      :  Utility functions for Strings
**
**  EXPORTED OBJECTS : 
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Jul 31, 2003
**      LAST UPDATE     : Jul 31, 2003
**      MODIFICATIONS   : 
**************************************************************************/

/*****************************
   $Log: string_utils.cpp,v $
   Revision 1.3  2003/12/04 09:57:35  arjen
   Transform non-ASCII characters into hexadecimal entities.

   Revision 1.2  2003/10/27 11:26:43  arjen
   Backslashes are correctly escaped with another backslash

   Revision 1.1  2003/08/05 08:15:01  arjen
   Debug output to the log stream instead of cerr.
   Fixed namespace problems in XPath searches of the DOM.
   Moved string utility functions to a separate file.

*****************************/

static const char *RCSID = "$Id: string_utils.cpp,v 1.3 2003/12/04 09:57:35 arjen Exp $";

#include <AXE/String.h>

/*=========================================================================
**  NAME           : SQL_Escape
**  SYNOPSIS       : String SQL_Escape(String)
**  PARAMETERS     : 
**  RETURN VALUE   : 
**
**  DESCRIPTION    : Insert backslashes before single quotes.
**
**  VARS USED      :
**  VARS CHANGED   :
**  FUNCTIONS USED :
**  SEE ALSO       :
**  LAST MODIFIED  : 
**=========================================================================
*/

String SQL_Escape(String s)
{
   int i;

   for (i = 0; i < ~s; i++)
   {
      if (s[i] == '\'' || s[i] == '\\')
      {
         s(i,0) = "\\";
         i++;
      }
   }

   return s;
}

/*=========================================================================
**  NAME           : XML_Entities
**  SYNOPSIS       : String XML_Entities(String)
**  PARAMETERS     : 
**  RETURN VALUE   : 
**
**  DESCRIPTION    : Replace special characters for XML with their entity codes:
**                          "<"  =>   "&lt;"
**                          ">"  =>   "&gt;"
**                          "&"  =>   "&amp;"
**                   Any non-ASCII characters or ASCII control codes are transformed
**                   into hexadecimal entities.
**
**  VARS USED      :
**  VARS CHANGED   :
**  FUNCTIONS USED :
**  SEE ALSO       :
**  LAST MODIFIED  : Nov 30, 2003
**=========================================================================
*/

String XML_Entities(String s)
{
   int i;

   for (i = 0; i < ~s; i++)
   {
      switch (s[i])
      {
      case '&':
         s(i,1) = "&amp;";
         i++;
         break;
      case '<':
         s(i,1) = "&lt;";
         i++;
         break;
      case '>':
         s(i,1) = "&gt;";
         i++;
         break;
      default:
         if ((s[i] & 0x80) != 0)
         {
            // Construct a hexadecimal entity
            const char hexdigit[] = "0123456789abcdef";
            char  entity[] = "&#x..;";

            entity[3] = hexdigit[(s[i] >> 4) & 0x0F];
            entity[4] = hexdigit[ s[i]       & 0x0F];

            s(i,1) = entity;
            i++;
         }
         else if (s[i] < ' ' && s[i] != '\t' && s[i] != '\r')
         {
            std::cerr << "WARNING: discarding illegal character " << int(s[i]) << "\n";
            s(i,1) = "";
            i++;
         }
      }
   }

   return s;
}
